#[non_exhaustive]pub enum ErrorKind {
Show 27 variants
Generic,
InternalMalfunction,
PermissionDenied,
OperationAborted,
DatabaseBusy,
DatabaseLocked,
OutOfMemory,
ReadOnly,
OperationInterrupted,
SystemIoFailure,
DatabaseCorrupt,
NotFound,
DiskFull,
CannotOpen,
FileLockingProtocolFailed,
SchemaChanged,
TooLarge,
ConstraintViolation,
DatatypeMismatch,
Misuse,
LfsUnsupported,
Unauthorized,
OutOfRange,
NotADatabase,
InvalidPath,
ConnectionClosed,
TooManyStatements,
}Expand description
Library error kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Generic
Generic error.
InternalMalfunction
Internal library error.
PermissionDenied
Unable to access the database.
OperationAborted
The operation has been aborted.
DatabaseBusy
Database is being used concurrently by the same process.
DatabaseLocked
Database is locked, usually because another process has opened it with read-write access.
OutOfMemory
Out of memory.
ReadOnly
Tried to write to a database which is read only.
OperationInterrupted
The operation has been interrupted.
SystemIoFailure
System I/O error.
DatabaseCorrupt
Database is corrupted.
NotFound
Database was not found.
DiskFull
Disk is full.
CannotOpen
Cannot open the database.
FileLockingProtocolFailed
Error in the file locking protocol.
SchemaChanged
Schema has changed.
TooLarge
String or blob is too large.
ConstraintViolation
Constraint violation.
DatatypeMismatch
Datatype mismatch.
Misuse
Library has been misused.
LfsUnsupported
No support for large files.
Statement is not authorized.
OutOfRange
Out of range.
NotADatabase
Not a database.
InvalidPath
Invalid path.
ConnectionClosed
Database was closed already.
TooManyStatements
Too many statements.
Implementations