pub struct Blob { /* private fields */ }Expand description
Binary blob.
Can be used to read and write to a blob. Reads and writes are buffered.
Created by Connection::open_blob.
Example
use futures::AsyncWriteExt;
let id = conn.insert("INSERT INTO my_table (column) VALUES (?);",
asqlite::params!(asqlite::ZeroBlob(4096))).await?;
let mut blob = conn.open_blob(
"main",
"my_table",
"column",
id,
asqlite::BlobOpenMode::ReadWrite,
).await?;
blob.write_all(b"example").await?;
blob.flush().await?;Implementations
Sourceimpl Blob
impl Blob
Sourcepub fn poll_read(
&mut self,
cx: &mut Context<'_>,
bytes: &mut [u8],
) -> Poll<Result<usize>>
pub fn poll_read( &mut self, cx: &mut Context<'_>, bytes: &mut [u8], ) -> Poll<Result<usize>>
Read some bytes into bytes.
See also: read.
Sourcepub fn poll_write(
&mut self,
cx: &mut Context<'_>,
bytes: &[u8],
) -> Poll<Result<usize>>
pub fn poll_write( &mut self, cx: &mut Context<'_>, bytes: &[u8], ) -> Poll<Result<usize>>
Write some bytes into buffer.
See also: write.
Sourcepub fn poll_flush(&mut self, cx: &mut Context<'_>) -> Poll<Result<()>>
pub fn poll_flush(&mut self, cx: &mut Context<'_>) -> Poll<Result<()>>
Flush written bytes to the database.
See also: flush.
Sourcepub fn poll_fill_buf(&mut self, cx: &mut Context<'_>) -> Poll<Result<&[u8]>>
pub fn poll_fill_buf(&mut self, cx: &mut Context<'_>) -> Poll<Result<&[u8]>>
Read the content of the internal buffer, filling it if empty.
See also: fill_buf.
Sourcepub fn consume(&mut self, bytes: usize)
pub fn consume(&mut self, bytes: usize)
Consume the internal buffer.
This function is a lower-level call that should be paired with
poll_fill_buf to work properly.
Sourcepub async fn read(&mut self, bytes: &mut [u8]) -> Result<usize>
pub async fn read(&mut self, bytes: &mut [u8]) -> Result<usize>
Read some bytes into buffer.
Returns the number of bytes read, or 0 when the EOF is reached.
Sourcepub async fn write(&mut self, bytes: &[u8]) -> Result<usize>
pub async fn write(&mut self, bytes: &[u8]) -> Result<usize>
Write some bytes into buffer.
Returns amount of bytes written.